#include <gtk/gtk.h>


gboolean
hsad_setup_assistant_delete_event        (GtkWidget       *widget,
					  GdkEvent        *event,
					  gpointer         user_data);

gboolean
hsad_setup_assistant_configure_event     (GtkWidget       *widget,
					  GdkEventConfigure *event,
					  gpointer         user_data);

void
hsad_setup_notebook_switch_page          (GtkNotebook     *notebook,
					  GtkNotebookPage *page,
					  guint            page_num,
					  gpointer         user_data);

void
hsad_quit_clicked                        (GtkButton       *button,
					  gpointer         user_data);

void
hsad_forward_clicked                     (GtkButton       *button,
					  gpointer         user_data);

void
hsad_print_clicked                       (GtkButton       *button,
					  gpointer         user_data);

void
hsad_privacy_clicked                     (GtkButton       *button,
					  gpointer         user_data);

void
hsad_back_clicked                        (GtkButton       *button,
					  gpointer         user_data);

void
hsad_accept_clicked                      (GtkButton       *button,
					  gpointer         user_data);

void
hsad_done_clicked                        (GtkButton       *button,
					  gpointer         user_data);

